##  Deliverables
Important features:
  * Welcome message to give introduction to companies strategy and deliverables deriving from that
  * Find reports and fact sheet charts that show the status of pursuing your companies strategy
    * e.g. a Cloud Migration Strategy
  * You might also want to include Metrics if applicable to show strategies development over time


### Example: Cloud Migration Strategy
  * Application landscape report with view on Cloud Migration Strategy
  * Report on cost per business capability
  * Fact sheet chart on tag group "Cloud Migration Strategies"


**Note**
In this example the fact sheet chart is making use of the tag group "Cloud Migration Strategies" with 4 Tags (Repurchase, Replatform, Retain, Retire).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275549ce7a441014a71a817712db412b_LowRes.png)
